# Topsis-Parth-102216063

This Python package implements the **TOPSIS** method (Technique for Order Preference by Similarity to Ideal Solution) for decision-making.

## Installation

You can install the package using pip:

```bash
pip install Topsis-Parth-102216063
